==> commons-2.1.1-alpha1-sources.jar: com/flybits/internal/db/UserDAO.java <==
package com.flybits.internal.db;

import androidx.lifecycle.LiveData;
import androidx.room.Dao;
import androidx.room.Insert;
import androidx.room.OnConflictStrategy;
import androidx.room.Query;
import androidx.room.Update;

import com.flybits.commons.library.models.User;

@Dao
public interface UserDAO {

    /**
     * @deprecated Use {@link #getActive()} as it will return a more accurate instance of the
     * currently active user.
     * deprecated in version 1.19.0, will be removed in version 3.0.0
     */
    @Query("Select * from user LIMIT 1")
    @Deprecated
    LiveData<User> get();

    /**
     * @deprecated Use {@link #getActiveUser()} as it will return a more accurate instance of the
     * currently active user.
     * deprecated in version 1.19.0, will be removed in version 3.0.0
     */
    @Query("Select * from user LIMIT 1")
    @Deprecated
    User getSingle();

    @Query("Select * from user WHERE id IN (:id) LIMIT 1")
    User getSingleById(String id);

    @Query("Select * from user WHERE isActive = 1 LIMIT 1")
    User getActiveUser();

    @Query("Select * from user WHERE isActive = 1 LIMIT 1")
    LiveData<User> getActive();

    @Query("Select * from user WHERE customerID IN (:customerID) and id IN (:userId) LIMIT 1")
    User getSingleByUserAndCustomerId(String userId, String customerID);

    @Query("Select * from user WHERE customerID IN (:customerID) LIMIT 1")
    User getSingleByCustomerId(String customerID);

    @Insert(onConflict = OnConflictStrategy.REPLACE)
    void insert(User plugins);

    @Query("Delete from user")
    void delete();

    @Query("Delete from user WHERE id IN (:id)")
    void deleteSingle(String id);

    @Update
    void update(User plugin);

    @Query("Update user set isActive = 0")
    void resetAllUsers();
}

==> commons-2.3.0-alpha1-sources.jar: com/flybits/internal/db/UserDAO.java <==
package com.flybits.internal.db;

import android.arch.lifecycle.LiveData;
import android.arch.persistence.room.Dao;
import android.arch.persistence.room.Insert;
import android.arch.persistence.room.OnConflictStrategy;
import android.arch.persistence.room.Query;
import android.arch.persistence.room.Update;

import com.flybits.commons.library.models.User;

@Dao
public interface UserDAO {

    /**
     * @deprecated Use {@link #getActive()} as it will return a more accurate instance of the
     * currently active user.
     * deprecated in version 1.19.0, will be removed in version 3.0.0
     */
    @Query("Select * from user LIMIT 1")
    @Deprecated
    LiveData<User> get();

    /**
     * @deprecated Use {@link #getActiveUser()} as it will return a more accurate instance of the
     * currently active user.
     * deprecated in version 1.19.0, will be removed in version 3.0.0
     */
    @Query("Select * from user LIMIT 1")
    @Deprecated
    User getSingle();

    @Query("Select * from user WHERE id IN (:id) LIMIT 1")
    User getSingleById(String id);

    @Query("Select * from user WHERE isActive = 1 LIMIT 1")
    User getActiveUser();

    @Query("Select * from user WHERE isActive = 1 LIMIT 1")
    LiveData<User> getActive();

    @Query("Select * from user WHERE customerID IN (:customerID) and id IN (:userId) LIMIT 1")
    User getSingleByUserAndCustomerId(String userId, String customerID);

    @Query("Select * from user WHERE customerID IN (:customerID) LIMIT 1")
    User getSingleByCustomerId(String customerID);

    @Insert(onConflict = OnConflictStrategy.REPLACE)
    void insert(User plugins);

    @Query("Delete from user")
    void delete();

    @Query("Delete from user WHERE id IN (:id)")
    void deleteSingle(String id);

    @Update
    void update(User plugin);

    @Query("Update user set isActive = 0")
    void resetAllUsers();
}
